@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -435,12 +435,15 @@ notify_user (const char *user, const char *device, const char *path,
 	return;
     }
 
-  if ((status = mu_mailbox_create (&mbox, path)) != 0 ||
-      (status = mu_mailbox_open (mbox,
+  if ((status = mu_mailbox_create (&mbox, path)) != 0)
+    {
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_create", path, status);
+      return;
+    }
+  if ((status = mu_mailbox_open (mbox,
 				 MU_STREAM_READ|MU_STREAM_QACCESS)) != 0)
     {
-      mu_error (_("cannot open mailbox %s: %s"),
-	      path, mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open", path, status);
       return;
     }
 
