@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -136,7 +136,7 @@ mailbox_truncate (mu_mailbox_t mbox)
 	      
       if ((rc = mu_iterator_current (itr, (void **)&m)) != 0)
 	{
-	  mu_error (_("can't get current message while truncating the mailbox: %s"),
+	  mu_error (_("cannot get current message while truncating the mailbox: %s"),
 		    mu_strerror (rc));
 	  exit (EX_OSERR);
 	}
@@ -207,13 +207,8 @@ main (int argc, char **argv)
   rc = mu_mailbox_create_default (&imbox, imbox_name);
   if (rc != 0)
     {
-      if (imbox_name)
-	mu_error (_("could not create mailbox `%s': %s"),
-		  imbox_name,
-		  mu_strerror (rc));
-      else
-	mu_error (_("could not create default mailbox: %s"),
-		  mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_create_default",
+		       imbox_name, rc);
       abend (EX_OSERR);
     }
 
@@ -223,8 +218,8 @@ main (int argc, char **argv)
       mu_url_t url = NULL;
 
       mu_mailbox_get_url (imbox, &url);
-      mu_error (_("could not open input mailbox `%s': %s"),
-		mu_url_to_string (url), mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open",
+		       mu_url_to_string (url), rc);
       abend (EX_NOINPUT);
     }
 
@@ -237,8 +232,8 @@ main (int argc, char **argv)
       rc = mu_mailbox_create_default (&ombox, ombox_name);
       if (rc != 0)
 	{
-	  mu_error (_("could not create output mailbox `%s': %s"),
-		    ombox_name,
+	  mu_error (_("could not create output mailbox %s: %s"),
+		    mu_quotename (ombox_name),
 		    mu_strerror (rc));
 	  abend (EX_OSERR);
 	}
@@ -260,8 +255,8 @@ main (int argc, char **argv)
 	      break;
 
 	    default:
-	      mu_error (_("could not open mailbox `%s': %s"),
-			ombox_name, mu_strerror (rc));
+	      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open",
+			       ombox_name, rc);
 	      abend (EX_OSERR);
 	    }
 	}	  
@@ -269,8 +264,7 @@ main (int argc, char **argv)
       rc = mu_mailbox_open (ombox, MU_STREAM_APPEND|MU_STREAM_CREAT);
       if (rc)
 	{
-	  mu_error (_("could not open mailbox `%s': %s"),
-		    ombox_name, mu_strerror (rc));
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open", ombox_name, rc);
 	  abend (EX_CANTCREAT);
 	}
 
