@@ -84,9 +84,7 @@ imap4d_create (struct imap4d_session *session,
 	    {
 	      if (mkdir (name, MKDIR_PERMISSIONS))
 		{
-		  mu_diag_output (MU_DIAG_ERR,
-				  _("Cannot create directory %s: %s"), name,
-				  mu_strerror (errno));
+		  mu_diag_funcall (MU_DIAG_ERR, "mkdir", name, errno);
 		  rc = RESP_NO;
 		}	  
 	    }
@@ -98,7 +96,7 @@ imap4d_create (struct imap4d_session *session,
 	      if (rc)
 		{
 		  mu_diag_output (MU_DIAG_ERR,
-				  _("Cannot create mailbox (%s) %s: %s"), name,
+				  _("cannot create mailbox (%s) %s: %s"), name,
 				  record->scheme,
 				  mu_strerror (rc));
 		  rc = RESP_NO;
@@ -107,10 +105,7 @@ imap4d_create (struct imap4d_session *session,
 					      MU_STREAM_RDWR | MU_STREAM_CREAT
 					      | mode)))
 		{
-		  mu_diag_output (MU_DIAG_ERR,
-				  _("Cannot open mailbox (%s) %s: %s"),
-				  record->scheme,
-				  name, mu_strerror (rc));
+		  mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open", name, rc);
 		  rc = RESP_NO;
 		}
 	      else
