@@ -360,10 +360,10 @@ do_search (struct parsebuf *pb)
 	    {
 	      size_t uid;
 	      mu_message_get_uid (pb->msg, &uid);
-	      io_sendf (" %s", mu_umaxtostr (0, uid));
+	      io_sendf (" %s", mu_umaxtostr (uid));
 	    }
 	  else
-	    io_sendf (" %s", mu_umaxtostr (0, pb->msgno));
+	    io_sendf (" %s", mu_umaxtostr (pb->msgno));
 	}
     }
   io_sendf ("\n");
@@ -949,7 +949,7 @@ _match_text (struct parsebuf *pb, mu_message_t msg, mu_content_type_t ct,
       mu_stream_unref (str);
       if (rc)
 	{
-	  mu_error (_("can't handle encoding %s: %s"),
+	  mu_error (_("cannot handle encoding %s: %s"),
 		    encoding, mu_strerror (rc));
 	  return 0;
 	}
@@ -975,7 +975,7 @@ _match_text (struct parsebuf *pb, mu_message_t msg, mu_content_type_t ct,
 	  mu_stream_unref (str);
 	  if (rc)
 	    {
-	      mu_error (_("can't convert from charset %s to %s"),
+	      mu_error (_("cannot convert from charset %s to %s"),
 			param->value, pb->charset);
 	      return 0;
 	    }
