@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2022 Free Software Foundation, Inc.
+   Copyright (C) 2011-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -45,6 +45,7 @@ struct mu_dbm_impl
   int (*_dbm_nextkey) (mu_dbm_file_t db, struct mu_dbm_datum *ret);
   void (*_dbm_datum_free) (struct mu_dbm_datum *datum);
   char const *(*_dbm_strerror) (mu_dbm_file_t db);
+  int (*_dbm_break) (mu_dbm_file_t db);
 };
 
 extern mu_url_t mu_dbm_hint;
@@ -65,6 +66,7 @@ int mu_dbm_store (mu_dbm_file_t db, struct mu_dbm_datum const *key,
 		  struct mu_dbm_datum const *contents, int replace);
 int mu_dbm_firstkey (mu_dbm_file_t db, struct mu_dbm_datum *ret);
 int mu_dbm_nextkey (mu_dbm_file_t db, struct mu_dbm_datum *ret);
+int mu_dbm_break (mu_dbm_file_t db);
 int mu_dbm_open (mu_dbm_file_t db, int flags, int mode);
 int mu_dbm_safety_get_owner (mu_dbm_file_t db, uid_t *uid);
 int mu_dbm_safety_get_flags (mu_dbm_file_t db, int *flags);
