@@ -307,6 +307,11 @@ int mu_file_safety_compose (int *res, const char *name, int defval);
 
 int mu_file_mode_to_safety_criteria (int mode);
 int mu_safety_criteria_to_file_mode (int crit);
+
+extern int mu_homedir_create;
+extern int mu_homedir_mode;
+
+int mu_homedir_assert (char const *dir, uid_t uid, gid_t gid);
   
 #ifdef __cplusplus
 }
