@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2019 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -480,39 +480,6 @@ mu_address_sget_email (mu_address_t addr, size_t no, char const **sptr)
 DECL_GET(email)
 DECL_AGET(email)
 
-size_t
-mu_address_format_string (mu_address_t addr, char *buf, size_t buflen)
-{
-  mu_stream_t str;
-  int rc;
-  
-  if (!buf)
-    rc = mu_nullstream_create (&str, MU_STREAM_WRITE);
-  else
-    rc = mu_fixed_memory_stream_create (&str, buf, buflen, MU_STREAM_WRITE);
-  if (rc == 0)
-    {
-      size_t size;
-      
-      mu_stream_stat_buffer statbuf;
-      mu_stream_set_stat (str, MU_STREAM_STAT_MASK (MU_STREAM_STAT_OUT),
-			  statbuf);
-      rc = mu_stream_format_address (str, addr);
-      mu_stream_destroy (&str);
-      if (rc)
-	return 0;
-      size = statbuf[MU_STREAM_STAT_OUT];
-      if (buf)
-	{
-	  if (size + 1 >= buflen)
-	    size = buflen - 1;
-	  buf[size] = 0;
-	}
-      return size;
-    }
-  return 0;
-}
-
 static int
 _address_is_group (mu_address_t addr)
 {
@@ -631,12 +598,6 @@ mu_address_get_printable (mu_address_t addr, char *buf, size_t len, size_t *n)
   return rc;
 }
 
-int
-mu_address_to_string (mu_address_t addr, char *buf, size_t len, size_t *n)
-{
-  return mu_address_get_printable (addr, buf, len, n);
-}
-
 int
 mu_address_get_count (mu_address_t addr, size_t *pcount)
 {
@@ -709,7 +670,7 @@ mu_address_contains_email (mu_address_t addr, const char *email)
 }
 
 static int
-mu_list_copy (mu_address_t dst, mu_address_t src)
+_address_copy (mu_address_t dst, mu_address_t src)
 {
   /* FIXME: How about:
     if (src->printable)
@@ -731,16 +692,46 @@ mu_list_copy (mu_address_t dst, mu_address_t src)
   return 0;
 }  
 
+static mu_address_t
+first_address_dup (mu_address_t src)
+{
+  mu_address_t dst = calloc (1, sizeof (*dst));
+  if (dst && _address_copy (dst, src))
+    {
+      mu_address_destroy (&dst);
+      return NULL;
+    }
+  return dst;
+}
+
 mu_address_t
 mu_address_dup (mu_address_t src)
 {
-  mu_address_t dst = calloc (1, sizeof (*dst));
+  mu_address_t head = NULL, tail = NULL;
 
-  if (!dst)
-    return NULL;
-  if (mu_list_copy (dst, src))
-    mu_address_destroy (&dst);
-  return dst;
+  while (src)
+    {
+      mu_address_t dst = calloc (1, sizeof (*dst));
+      if (!dst)
+	{
+	  mu_address_destroy (&head);
+	  return NULL;
+	}
+
+      if (tail)
+	tail->next = dst;
+      else
+	head = dst;
+      tail = dst;
+      
+      if (_address_copy (dst, src))
+	{
+	  mu_address_destroy (&head);
+	  return NULL;
+	}
+      src = src->next;
+    }
+  return head;
 }
 
 int
@@ -756,41 +747,26 @@ mu_address_union (mu_address_t *a, mu_address_t b)
       *a = mu_address_dup (b);
       if (!*a)
 	return ENOMEM;
-      last = *a;
-      b = b->next;
+      return 0;
     }
-  else
+
+  if ((*a)->printable)
     {
-      if ((*a)->printable)
-	{
-	  free ((*a)->printable);
-	  (*a)->printable = NULL;
-	}
-      for (last = *a; last->next; last = last->next)
-	;
+      free ((*a)->printable);
+      (*a)->printable = NULL;
     }
+  for (last = *a; last->next; last = last->next)
+    ;
 
   for (; b; b = b->next)
     if (!mu_address_contains_email (*a, b->email))
       {
-	if (last->email)
-	  {
-	    mu_address_t next = mu_address_dup (b);
-	    if (!next)
-	      return ENOMEM;
-	    last->next = next;
-	    last = next;
-	  }
-	else
-	  {
-	    int rc = mu_list_copy (last, b);
-	    if (rc)
-	      {
-		_address_free (last);
-		memset (last, 0, sizeof (*last));
-		return rc;
-	      }
-	  }
+	mu_address_t next = first_address_dup (b);
+	if (!next)
+	  return ENOMEM;
+	last->next = next;
+	last = next;
       }
+
   return 0;
 }
