@@ -475,19 +475,25 @@ amd_open (mu_mailbox_t mailbox, int flags)
       if ((flags & MU_STREAM_CREAT) && errno == ENOENT)
 	{
 	  int rc;
-	  int perms = mu_stream_flags_to_mode (flags, 1);
-	  if (mkdir (amd->name, S_IRUSR|S_IWUSR|S_IXUSR|perms))
-	    return errno;
-	  if (stat (amd->name, &st) < 0)
-	    return errno;
+	  int perms = mu_stream_flags_to_mode (flags, 1) |
+	               S_IRUSR|S_IWUSR|S_IXUSR;
+	  int u = umask (0);
+	  if (flags & MU_STREAM_INTERDIR)
+	    rc = mu_mkinterdir (amd->name, perms, perms);
+	  else if (mkdir (amd->name, S_IRUSR|S_IWUSR|S_IXUSR|perms))
+	    rc = errno;
+	  else
+	    rc = 0;
+	  umask (u);
+	  if (rc)
+	    return rc;
 	  if (amd->create && (rc = amd->create (amd, flags)))
 	    return rc;
 	}
       else
 	return errno;
     }
-    
-  if (!S_ISDIR (st.st_mode))
+  else if (!S_ISDIR (st.st_mode))
     return EINVAL;
 
   if (access (amd->name,
