@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2016-2020 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -52,8 +52,8 @@ mu_copy_file (const char *srcpath, const char *dstpath, int flags)
   if (((flags & MU_COPY_DEREF) ? stat : lstat) (srcpath, &st))
     {
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("can't stat file %s: %s"),
-		 srcpath, mu_strerror (errno)));
+		(_("%s(%s) failed: %s"),
+		 "stat", srcpath, mu_strerror (errno)));
       return errno;
     }
 
@@ -65,7 +65,7 @@ mu_copy_file (const char *srcpath, const char *dstpath, int flags)
 	  if (rc)
 	    {
 	      mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-			(_("can't remove destination %s: %s"),
+			(_("cannot remove destination %s: %s"),
 			 dstpath, mu_strerror (rc)));
 	      return rc;
 	    }
@@ -209,7 +209,8 @@ copy_regular_file (const char *srcpath, const char *dstpath, int flags,
       else
 	{
 	  mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		    (_("can't change file mode and ownership after copying %s to %s;"
+		    (_("cannot change file mode and ownership after"
+		       " copying %s to %s;"
 		       " cannot get file handle: %s"),
 		     srcpath, dstpath,
 		     mu_strerror (rc)));
@@ -242,7 +243,7 @@ copy_symlink (const char *srcpath, const char *dstpath)
     {
       rc = errno;
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("%s: can't link %s to %s: %s"),
+		(_("%s: cannot link %s to %s: %s"),
 		 srcpath, buf, dstpath, mu_strerror (rc)));
     }
   free (buf);
@@ -261,8 +262,8 @@ copy_dir (const char *srcpath, const char *dstpath, int flags)
   if (stat (srcpath, &st))
     {
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("can't stat file %s: %s"),
-		 srcpath, mu_strerror (errno)));
+		(_("%s(%s) failed: %s"),
+		 "stat", srcpath, mu_strerror (errno)));
       return errno;
     }
 
@@ -275,7 +276,7 @@ copy_dir (const char *srcpath, const char *dstpath, int flags)
   if (rc)
     {
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("can't create directory %s: %s"),
+		("mkdir(%s): %s",
 		 dstpath, mu_strerror (errno)));
       return errno;
     }
