@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2003, 2005-2007, 2009-2012, 2014-2018 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -57,62 +56,6 @@ mu_mh_delim (const char *str)
   return str[0] == '\n';
 }
 
-int
-mutil_parse_field_map (const char *map, mu_assoc_t *passoc_tab, int *perr)
-{
-  int rc;
-  int i;
-  struct mu_wordsplit ws;
-  mu_assoc_t assoc_tab = NULL;
-
-  ws.ws_delim = ":";
-  if (mu_wordsplit (map, &ws, MU_WRDSF_DEFFLAGS|MU_WRDSF_DELIM))
-    {
-      mu_error (_("cannot split line `%s': %s"), map,
-		mu_wordsplit_strerror (&ws));
-      return errno;
-    }
-
-  for (i = 0; i < ws.ws_wordc; i++)
-    {
-      char *tok = ws.ws_wordv[i];
-      char *p = strchr (tok, '=');
-      char *pptr;
-      
-      if (!p)
-	{
-	  rc = EINVAL;
-	  break;
-	}
-      if (!assoc_tab)
-	{
-	  rc = mu_assoc_create (&assoc_tab, 0);
-	  if (rc)
-	    break;
-	  mu_assoc_set_destroy_item (assoc_tab, mu_list_free_item);
-	  *passoc_tab = assoc_tab;
-	}
-      *p++ = 0;
-      pptr = strdup (p);
-      if (!pptr)
-	{
-	  rc = errno;
-	  break;
-	}
-      rc = mu_assoc_install (assoc_tab, tok, pptr);
-      if (rc)
-	{
-	  free (p);
-	  break;
-	}
-    }
-
-  mu_wordsplit_free (&ws);
-  if (rc && perr)
-    *perr = i;
-  return rc;
-}
-
 int
 mu_stream_flags_to_mode (int flags, int isdir)
 {
