@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2007-2023 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -44,7 +44,7 @@ static struct mu_conf_option mu_conf_option[] = {
   { "USE_LIBPAM", N_("PAM support") },
 #endif
 #ifdef HAVE_LIBLTDL
-  { "HAVE_LIBLTDL", N_("a portable `dlopen' wrapper library") },
+  { "HAVE_LIBLTDL", N_("a portable 'dlopen' wrapper library") },
 #endif
 #ifdef WITH_BDB2
   { "WITH_BDB2", N_("Berkeley DB v. 2") },
