@@ -261,9 +261,9 @@ void
 mu_acl_cfg_init (void)
 {
   struct mu_cfg_section *section;
-  if (mu_create_canned_section ("acl", &section) == 0)
+  if (mu_create_canned_section_ext ("acl", DEFAULT_TEXT_DOMAIN, &section) == 0)
     {
       section->parser = acl_section_parser;
-      mu_cfg_section_add_params (section, acl_param);
+      mu_cfg_section_add_params_ext (section, acl_param, DEFAULT_TEXT_DOMAIN);
     }
 }
