@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003-2024 Free Software Foundation, Inc.
+   Copyright (C) 2003-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -85,7 +85,7 @@ _from_decoder (void *xd,
 		{
 		  if (i == 0)
 		    {
-		      iobuf->isize = GT_FROM_MARK_LEN - len;
+		      iobuf->isize += GT_FROM_MARK_LEN - len;
 		      return mu_filter_moreinput;
 		    }
 		  break;
@@ -216,7 +216,7 @@ _from_encoder (void *xd,
 		{
 		  if (i == 0)
 		    {
-		      iobuf->isize = FROM_MARK_LEN;
+		      iobuf->isize += FROM_MARK_LEN;
 		      return mu_filter_moreinput;
 		    }
 		  break;
@@ -234,7 +234,7 @@ _from_encoder (void *xd,
 		{
 		  if (i == 0)
 		    {
-		      iobuf->osize = GT_FROM_MARK_LEN;
+		      iobuf->osize += GT_FROM_MARK_LEN;
 		      return mu_filter_moreoutput;
 		    }
 		  break;
