@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -164,11 +164,13 @@ mu_construct_user_mailbox_url (char **pout, const char *name)
     {
       if (rc == MU_ERR_FAILURE)
 	{
-	  mu_error (_("cannot expand line `%s': %s"), pat, result);
+	  mu_error (_("cannot expand line %s: %s"), mu_quotename (pat),
+		    result);
 	  free (result);
 	}
       else
-	mu_error (_("cannot expand line `%s': %s"), pat, mu_strerror (rc));
+	mu_error (_("cannot expand line %s: %s"), mu_quotename (pat),
+		  mu_strerror (rc));
       return rc;
     }
 
@@ -299,7 +301,7 @@ plus_expand (const char *file, char **buf)
   else
     {
       file++;
-  
+
       if (folder_dir[0] == '/' || mu_is_proto (folder_dir))
 	{
 	  char *p = mu_make_file_name (folder_dir, file);
