@@ -1,6 +1,6 @@
 /* Operations on RFC-2231-compliant mail headers fields.
    GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2023 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -614,7 +614,7 @@ _mime_header_parse (const char *text, char **pvalue,
 		    MU_WRDSF_RETURN_DELIMS | MU_WRDSF_WS | MU_WRDSF_OPTIONS))
     {
       mu_debug (MU_DEBCAT_MIME, MU_DEBUG_ERROR,
-		(_("wordsplit: %s"), mu_wordsplit_strerror (&ws)));
+		("wordsplit: %s", mu_wordsplit_strerror (&ws)));
       mu_wordsplit_free (&ws);
       free (value);
       return MU_ERR_PARSE;
@@ -646,7 +646,7 @@ _mime_header_parse (const char *text, char **pvalue,
 	      if (p)
 		{
 		  mu_debug (MU_DEBCAT_MIME, MU_DEBUG_TRACE0,
-			    (_("finished error recovery at ; %s"),
+			    (_("finished error recovery at \"; %s\""),
 			     ws.ws_wordv[i]));
 		  /* put the semicolon back */
 		  i--;
