@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2024 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -117,7 +117,7 @@ _mh_prop_read_stream (mu_header_t *phdr, mu_stream_t stream)
 			      MU_FILTER_DECODE, MU_STREAM_READ);
   if (rc)
     {
-      mu_error (_("cannot open filter stream: %s"), mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_filter_create_args", argv[0], rc);
       return rc;
     }
 
