@@ -145,8 +145,7 @@ static struct mu_cfg_param mu_sql_param[] = {
     N_("arg: plain|hash|crypt|scrambled") },
   { "field-map", mu_cfg_callback, NULL, 0, cb_field_map,
     N_("Set a field-map for parsing SQL replies.  The map is a "
-       "column-separated list of definitions.  Each definition has the "
-       "following form:\n"
+       "list of definitions, each of which has the following form:\n"
        "   <name: string>=<column: string>\n"
        "where <name> is one of the following: name, passwd, uid, gid, "
        "gecos, dir, shell, mailbox, quota, and <column> is the name of "
