@@ -205,23 +205,23 @@ cli_clear_library_path (struct mu_parseopt *po, struct mu_option *opt,
 }
 
 static struct mu_option sieve_option[] = {
-  MU_OPTION_GROUP (N_("Sieve options")),
+  MU_OPTION_GROUP_EXT (N_("Sieve options"), DEFAULT_TEXT_DOMAIN),
   { "includedir", 'I', N_("DIR"), MU_OPTION_DEFAULT,
     N_("append DIR to the list of directories searched for include files"),
-    mu_c_string, NULL, cli_includedir },
+    mu_c_string, NULL, cli_includedir, NULL, DEFAULT_TEXT_DOMAIN },
   { "libdir", 'L', N_("DIR"), MU_OPTION_DEFAULT,
     N_("append DIR to the list of directories searched for library files"),
-    mu_c_string, NULL, cli_libdir },
+    mu_c_string, NULL, cli_libdir, NULL, DEFAULT_TEXT_DOMAIN },
   { "libdir-prefix", 0, N_("DIR"), MU_OPTION_DEFAULT,
     N_("add DIR to the beginning of the list of directories searched for "
        "library files"),
-    mu_c_string, NULL, cli_libdir_prefix },
+    mu_c_string, NULL, cli_libdir_prefix, NULL, DEFAULT_TEXT_DOMAIN },
   { "clear-include-path", 0, NULL, MU_OPTION_DEFAULT,
     N_("clear Sieve include path"),
-    mu_c_string, NULL, cli_clear_include_path },
+    mu_c_string, NULL, cli_clear_include_path, NULL, DEFAULT_TEXT_DOMAIN },
   { "clear-library-path", 0, NULL, MU_OPTION_DEFAULT,
     N_("clear Sieve library path"),
-    mu_c_string, NULL, cli_clear_library_path },
+    mu_c_string, NULL, cli_clear_library_path, NULL, DEFAULT_TEXT_DOMAIN },
   { "clearpath", 0, NULL, MU_OPTION_ALIAS },
   MU_OPTION_END
 };
@@ -253,5 +253,6 @@ struct mu_cli_capa mu_cli_capa_sieve = {
   sieve_option,
   mu_sieve_param,
   NULL,
-  sieve_commit
+  sieve_commit,
+  DEFAULT_TEXT_DOMAIN
 };
