@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2023 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -70,10 +70,14 @@ retrieve_address (void *item, void *data, size_t idx, char **pval)
 	return MU_ERR_NOENT;
       rc = mu_address_create (&ap->addr, val);
       free (val);
-      if (rc)
+      switch (rc)
         {
-          if (rc == MU_ERR_EMPTY_ADDRESS)
-            rc = MU_ERR_NOENT;
+	case 0:
+	  break;
+	case MU_ERR_INVALID_EMAIL:
+	case MU_ERR_EMPTY_ADDRESS:
+	  return MU_ERR_NOENT;
+	default:
           return rc;
         }
     }
@@ -217,8 +221,16 @@ retrieve_envelope (void *item, void *data, size_t idx, char **pval)
 	return rc;
 
       rc = mu_address_create (&ap->addr, buf);
-      if (rc)
-	return rc;
+      switch (rc)
+        {
+	case 0:
+	  break;
+	case MU_ERR_INVALID_EMAIL:
+	case MU_ERR_EMPTY_ADDRESS:
+	  return MU_ERR_NOENT;
+	default:
+          return rc;
+        }
     }
 
   rc = ap->aget (ap->addr, idx+1, pval);
