@@ -287,7 +287,7 @@ set_tag_checker (mu_sieve_machine_t mach)
 	  else if (prec == tmp_prec)
 	    {
 	      mu_diag_at_locus_range (MU_LOG_ERROR, &t->locus,
-				      _("%s and %s can't be used together"),
+				      _("%s and %s cannot be used together"),
 				      tmp.tag, t->tag);
 	      mu_diag_at_locus_range (MU_LOG_ERROR, &tmp.locus,
 				      _("%s encountered here"),
