@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2011-2021 Free Software Foundation, Inc.
+   Copyright (C) 2011-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -107,7 +107,7 @@ _save_message_parser (void *item, void *data)
       if (rc)
 	{
 	  mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
-		    (_("mu_static_memory_stream_create: %s"),
+		    ("mu_static_memory_stream_create: %s",
 		     mu_strerror (rc)));
 	  imbx->last_error = rc;
 	  return 0;
@@ -119,7 +119,7 @@ _save_message_parser (void *item, void *data)
       if (rc)
 	{
 	  mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
-		    (_("mu_filter_create: %s"), mu_strerror (rc)));
+		    ("mu_filter_create: %s", mu_strerror (rc)));
 	  imbx->last_error = rc;
 	  return 0;
 	}
@@ -136,6 +136,7 @@ _save_message_parser (void *item, void *data)
       clos->size = size;
     }
   else
+    /* TRANSLATORS: "fetch" is the name of an IMAP command. */
     mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_TRACE0,
 	      (_("fetch returned a not requested item %d"),
 	       resp->type));
@@ -174,7 +175,7 @@ __imap_msg_get_stream (struct _mu_imap_message *imsg, size_t msgno,
 	  mu_stream_set_buffer (imbx->cache, mu_buffer_full, 8192);
 	}
 
-      rc = mu_stream_size (imbx->cache, &imsg->offset);
+      rc = mu_stream_seek (imbx->cache, 0, MU_SEEK_END, &imsg->offset);
       if (rc)
 	return rc;
 
@@ -509,8 +510,7 @@ _imap_msg_lines (mu_message_t msg, size_t *plines, int quick)
 
       if (quick && !(imsg->flags & _MU_IMAP_MSG_CACHED))
 	return MU_ERR_INFO_UNAVAILABLE;
-      if (!_imap_mbx_uptodate (imbx))
-	_imap_mbx_scan (mbox, 1, NULL);
+      _imap_mbx_scan (mbox, 1, NULL);
       rc = _imap_msg_scan (imsg);
       if (rc)
 	return rc;
@@ -578,6 +578,7 @@ fetch_bodystructure_parser (void *item, void *data)
       resp->bodystructure.bs = NULL;
     }
   else
+    /* TRANSLATORS: "fetch" is the name of an IMAP command. */
     mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_TRACE0,
 	      (_("fetch returned a not requested item %d"),
 	       resp->type));
@@ -620,6 +621,14 @@ _imap_msg_detach (mu_message_t msg)
   imsg->message = NULL;
 }
 
+static int
+_imap_msg_uid (mu_message_t msg, size_t *retuid)
+{
+  struct _mu_imap_message *imsg = mu_message_get_owner (msg);
+  *retuid = imsg->uid;
+  return 0;
+}
+
 static int
 _imap_mbx_get_message (mu_mailbox_t mailbox, size_t msgno, mu_message_t *pmsg)
 {
@@ -628,8 +637,7 @@ _imap_mbx_get_message (mu_mailbox_t mailbox, size_t msgno, mu_message_t *pmsg)
   int rc;
 
   /* If we did not start a scanning yet do it now.  */
-  if (!_imap_mbx_uptodate (imbx))
-    _imap_mbx_scan (mailbox, 1, NULL);
+  _imap_mbx_scan (mailbox, 1, NULL);
 
   if (msgno > imbx->msgs_cnt)
     return MU_ERR_NOENT;
@@ -642,14 +650,15 @@ _imap_mbx_get_message (mu_mailbox_t mailbox, size_t msgno, mu_message_t *pmsg)
       rc = mu_message_create (&msg, imsg);
       if (rc)
 	return rc;
-      
+
       msg->_detach = _imap_msg_detach;
-	
+
       mu_message_set_get_stream (msg, _imap_msg_get_stream, imsg);
       mu_message_set_size (msg, _imap_msg_size, imsg);
       mu_message_set_lines (msg, _imap_msg_lines, imsg);
       mu_message_set_imapenvelope (msg, _imap_msg_imapenvelope, imsg);
       mu_message_set_bodystructure (msg, _imap_msg_bodystructure, imsg);
+      mu_message_set_uid (msg, _imap_msg_uid, imsg);
 
       do
 	{
@@ -801,8 +810,6 @@ _imap_mbx_open (mu_mailbox_t mbox, int flags)
   if (imbx->stats.flags & MU_IMAP_STAT_MESSAGE_COUNT)
     rc = _imap_realloc_messages (imbx, imbx->stats.message_count);
 
-  _imap_mbx_scan (mbox, 1, NULL);
-
   return rc;
 }
 
@@ -1114,7 +1121,8 @@ _imap_mbx_sync (mu_mailbox_t mbox)
 }
 
 static int
-_imap_mbx_append_message (mu_mailbox_t mbox, mu_message_t msg)
+_imap_mbx_append_message (mu_mailbox_t mbox, mu_message_t msg,
+			  mu_envelope_t env, mu_attribute_t atr)
 {
   int rc;
   mu_folder_t folder = mbox->folder;
@@ -1128,7 +1136,8 @@ _imap_mbx_append_message (mu_mailbox_t mbox, mu_message_t msg)
   rc = mu_url_sget_path (url, &mbox_name);
   if (rc)
     return rc;
-  return mu_imap_append_message (imap, mbox_name, 0, NULL, NULL, msg);
+
+  return mu_imap_append_message (imap, mbox_name, msg, env, atr);
 }
 
 static int _compute_lines (struct mu_bodystructure *bs, size_t *pcount);
@@ -1229,6 +1238,7 @@ fetch_response_parser (void *item, void *data)
       break;
 
     default:
+      /* TRANSLATORS: "fetch" is the name of an IMAP command. */
       mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_TRACE0,
 		(_("fetch returned a not requested item %d"),
 		 resp->type));
@@ -1294,6 +1304,9 @@ _imap_mbx_scan (mu_mailbox_t mbox, size_t msgno, size_t *pcount)
   int rc;
   static char _imap_scan_items[] = "(UID FLAGS ENVELOPE RFC822.SIZE BODY BODY.PEEK[HEADER])";
 
+  if (_imap_mbx_uptodate (imbx))
+    return 0;
+
   mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_TRACE1,
 	    (_("scanning mailbox %s"), mu_url_to_string (mbox->url)));
   if (imbx->stats.message_count > 0)
@@ -1316,20 +1329,19 @@ _imap_mbx_scan (mu_mailbox_t mbox, size_t msgno, size_t *pcount)
 	rc = _imap_mbx_errno (imbx);
       if (rc == 0)
 	{
-	  size_t i;
-	  mu_off_t total = 0;
-
 	  imbx->flags |= _MU_IMAP_MBX_UPTODATE;
 
-	  for (i = 1; i <= imbx->msgs_cnt; i++)
+	  if (mbox->observable)
 	    {
-	      total += imbx->msgs[i-1]->message_size;
+	      size_t i;
+
 	      /* MU_EVT_MESSAGE_ADD must be delivered only when it is already
 		 possible to retrieve the message in question.  It could not be
-		 done in the fetch handler for obvious reasons.  Hence the extra
-		 loop. */
-	      if (mbox->observable)
-		mu_observable_notify (mbox->observable, MU_EVT_MESSAGE_ADD, &i);
+		 done in the fetch handler for obvious reasons.  Hence the
+		 extra loop. */
+	      for (i = 1; i <= imbx->msgs_cnt; i++)
+		mu_observable_notify (mbox->observable, MU_EVT_MESSAGE_ADD,
+				      &i);
 	    }
 	  if (pcount)
 	    *pcount = imbx->msgs_cnt;
@@ -1357,7 +1369,7 @@ _imap_mbx_is_updated (mu_mailbox_t mbox)
   if (rc)
     {
       mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
-		(_("mu_imap_noop: %s"), mu_strerror (rc)));
+		("mu_imap_noop: %s", mu_strerror (rc)));
       imbx->last_error = rc;
     }
   return _imap_mbx_uptodate(imbx);
@@ -1380,7 +1392,7 @@ _imap_copy_to_mailbox (mu_mailbox_t mbox, mu_msgset_t msgset,
   if (rc)
     {
       mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
-		(_("mu_imap_copy: %s"), mu_strerror (rc)));
+		("mu_imap_copy: %s", mu_strerror (rc)));
       if (rc)
 	{
 	  if (mu_imap_response_code (imap) == MU_IMAP_RESPONSE_TRYCREATE)
