@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2008-2022 Free Software Foundation, Inc.
+   Copyright (C) 2008-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -335,9 +335,14 @@ url_to_argv (mu_url_t url, mu_message_t msg,
     {
       if (mu_wordsplit (query[i], &ws, wsflags))
 	{
+	  /* Translate wordsplit error into mailutils (or system) one */
+	  if (ws.ws_errno == WRDSE_NOSPACE)
+	    rc = ENOMEM;
+	  else
+	    rc = MU_ERR_PARSE;
 	  mu_argcv_free (i, argv);
 	  mu_wordsplit_free (&ws);
-	  return errno;
+	  return rc;
 	}
       if (ws.ws_wordc == 0)
 	argv[i+1] = strdup ("");
