@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2012 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
@@ -22,6 +22,7 @@
 #include <mailutils/list.h>
 #include <mailutils/secret.h>
 #include <mailutils/smtp.h>
+#include <mailutils/url.h>
 #include <mailutils/stream.h>
 #include <mailutils/sys/smtp.h>
 
@@ -66,6 +67,7 @@ mu_smtp_destroy (mu_smtp_t *psmtp)
 	mu_secret_password_unref (smtp->secret);
       mu_secret_destroy (&smtp->secret);
     }
+  mu_url_destroy (&smtp->url);
   
   for (i = 0; i < MU_SMTP_MAX_PARAM; i++)
     {
