@@ -94,8 +94,8 @@ messages_count (const char *box)
   if (status != 0)
     {
       if (box)
-	mu_error (_("could not create mailbox `%s': %s"),
-		  box, mu_strerror (status));
+	mu_error (_("could not create mailbox %s: %s"),
+		  mu_quotename (box), mu_strerror (status));
       else
 	mu_error (_("could not create default mailbox: %s"),
 		  mu_strerror (status));
@@ -108,16 +108,15 @@ messages_count (const char *box)
   status =  mu_mailbox_open (mbox, MU_STREAM_READ);
   if (status != 0)
     {
-      mu_error (_("could not open mailbox `%s': %s"),
-		box, mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open", box, status);
       return -1;
     }
 
   status = mu_mailbox_messages_count (mbox, &count);
   if (status != 0)
     {
-      mu_error (_("could not count messages in mailbox `%s': %s"),
-		box, mu_strerror (status));
+      mu_error (_("could not count messages in mailbox %s: %s"),
+		mu_quotename (box), mu_strerror (status));
       return -1;
     }
 
@@ -130,8 +129,8 @@ messages_count (const char *box)
   status = mu_mailbox_close (mbox);
   if (status != 0)
     {
-      mu_error (_("could not close `%s': %s"),
-		box, mu_strerror (status));
+      mu_error (_("could not close %s: %s"),
+		mu_quotename (box), mu_strerror (status));
       return -1;
     }
 
