@@ -298,7 +298,7 @@ _scan (const char *name, size_t depth, size_t skip_prefix_len)
   
   if (info.cur)
     {
-      p = mh_safe_make_file_name (name, mu_umaxtostr (0, info.cur));
+      p = mh_safe_make_file_name (name, mu_umaxtostr (info.cur));
       if (stat (p, &st) < 0 || !S_ISREG (st.st_mode))
 	info.cur = 0;
       free (p);
@@ -470,7 +470,7 @@ get_stack (size_t *pc, char ***pv)
     }
   else if (mu_wordsplit (stack, &ws, MU_WRDSF_DEFFLAGS))
     {
-      mu_error (_("cannot split line `%s': %s"), stack,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (stack),
 		mu_wordsplit_strerror (&ws));
       exit (1);
     }
@@ -602,8 +602,8 @@ pack_rename (struct pack_tab *tab, int reverse)
   const char *s2;
   const char *from, *to;
   
-  s1 = mu_umaxtostr (0, tab->orig);
-  s2 = mu_umaxtostr (1, tab->new);
+  s1 = mu_umaxtostr_n (0, tab->orig);
+  s2 = mu_umaxtostr_n (1, tab->new);
 
   if (!reverse)
     {
@@ -617,13 +617,15 @@ pack_rename (struct pack_tab *tab, int reverse)
     }
 
   if (verbose)
-    fprintf (stderr, _("Renaming %s to %s\n"), from, to);
+    fprintf (stderr, _("Renaming %s to %s\n"),
+	     mu_quotename_n (0, from), mu_quotename_n (1, to));
 
   if (!dry_run)
     {
       if ((rc = rename (from, to)))
-	mu_error (_("cannot rename `%s' to `%s': %s"),
-		  from, to, mu_strerror (errno));
+	mu_error (_("cannot rename %s to %s: %s"),
+		  mu_quotename_n (0, from), mu_quotename_n (1, to),
+		  mu_strerror (errno));
     }
   else
     rc = 0;
@@ -663,19 +665,19 @@ roll_back (const char *folder_name, struct pack_tab *pack_tab, size_t i)
   do
     if (pack_rename (pack_tab + i, 1))
       {
-	mu_error (_("CRITICAL ERROR: Folder `%s' left in an inconsistent state, because an error\n"
+	mu_error (_("CRITICAL ERROR: Folder %s left in an inconsistent state, because an error\n"
 		    "occurred while trying to roll back the changes.\n"
 		    "Message range %s-%s has been renamed to %s-%s."),
-		  folder_name,
-		  mu_umaxtostr (0, pack_tab[0].orig),
-                  mu_umaxtostr (1, pack_tab[start].orig),
-		  mu_umaxtostr (2, pack_tab[0].new),
-                  mu_umaxtostr (3, pack_tab[start].new));
+		  mu_quotename (folder_name),
+		  mu_umaxtostr_n (0, pack_tab[0].orig),
+                  mu_umaxtostr_n (1, pack_tab[start].orig),
+		  mu_umaxtostr_n (2, pack_tab[0].new),
+                  mu_umaxtostr_n (3, pack_tab[start].new));
 	mu_error (_("You will have to fix it manually."));
 	exit (1);
       }
   while (i-- > 0);
-  mu_error (_("folder `%s' restored successfully"), folder_name);
+  mu_error (_("folder %s restored successfully"), mu_quotename (folder_name));
 }
 
 struct fixup_data
@@ -722,7 +724,7 @@ _fixup (const char *name, const char *value, struct fixup_data *fd, int flags)
 
   if (mu_wordsplit (value, &ws, MU_WRDSF_DEFFLAGS))
     {
-      mu_error (_("cannot split line `%s': %s"), value,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (value),
 		mu_wordsplit_strerror (&ws));
       return;
     }
@@ -837,7 +839,7 @@ action_pack (void)
     fprintf (stderr, ngettext ("%s message number collected.\n",
 			       "%s message numbers collected.\n",
 			       (unsigned long) count),
-	     mu_umaxtostr (0, count));
+	     mu_umaxtostr (count));
   
   mu_mailbox_close (mbox);
   mu_mailbox_destroy (&mbox);
@@ -860,8 +862,8 @@ action_pack (void)
   status = chdir (folder_dir);
   if (status)
     {
-      mu_error (_("cannot change to directory `%s': %s"),
-		folder_dir, mu_strerror (status));
+      mu_error (_("cannot change to %s: %s"),
+		mu_quotename (folder_dir), mu_strerror (status));
       return 1;
     }
 
