@@ -354,8 +354,7 @@ mh_makedir (const char *p)
     {
       rc = mkdir (p, perm);
       if (rc)
-	mu_error (_("cannot create directory %s: %s"),
-		  p, strerror (errno));
+	mu_diag_funcall (MU_DIAG_ERROR, "mkdir", p, errno);
     }
 
   umask (save_umask);
@@ -379,7 +378,7 @@ mh_check_folder (const char *pathname, int confirm)
 	{
 	  /* TRANSLATORS: This is a question and will be followed
 	     by question mark on output. */
-	  if (!confirm || mh_getyn (_("Create folder \"%s\""), p))
+	  if (!confirm || mh_getyn (_("Create folder %s"), mu_quotename (p)))
 	    return mh_makedir (p);
 	  else
 	    return 1;
@@ -680,7 +679,7 @@ mh_spawnp (const char *prog, const char *file)
   ws.ws_comment = "#";
   if (mu_wordsplit (prog, &ws, MU_WRDSF_DEFFLAGS | MU_WRDSF_COMMENT))
     {
-      mu_error (_("cannot split line `%s': %s"), prog,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (prog),
 		mu_wordsplit_strerror (&ws));
       return 1;
     }
@@ -717,15 +716,14 @@ mh_file_copy (const char *from, const char *to)
   
   if ((rc = mu_file_stream_create (&in, from, MU_STREAM_READ)))
     {
-      mu_error (_("cannot open input file `%s': %s"),
-		from, mu_strerror (rc));
+      mu_error (_("cannot open input file %s: %s"),
+		mu_quotename (from), mu_strerror (rc));
       return 1;
     }
 
   if ((rc = mu_file_stream_create (&out, to, MU_STREAM_RDWR|MU_STREAM_CREAT)))
     {
-      mu_error (_("cannot open output file `%s': %s"),
-		to, mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create", to, rc);
       mu_stream_destroy (&in);
       return 1;
     }
@@ -735,7 +733,8 @@ mh_file_copy (const char *from, const char *to)
   mu_stream_unref (in);
   if (rc)
     {
-      mu_error (_("cannot open filter stream: %s"), mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_filter_create",
+		       "INLINE-COMMENT", rc);
       mu_stream_destroy (&out);
       return 1;
     }
@@ -746,8 +745,10 @@ mh_file_copy (const char *from, const char *to)
   mu_stream_destroy (&out);
 
   if (rc)
-    mu_error (_("error copying file `%s' to `%s': %s"),
-	      from, to, mu_strerror (rc));
+    mu_error (_("error copying file %s to %s: %s"),
+	      mu_quotename_n (0, from),
+	      mu_quotename_n (1, to),
+	      mu_strerror (rc));
   
   return rc;
 }
@@ -826,7 +827,8 @@ mh_real_install (char *name, int automode)
 
       /* TRANSLATORS: This is a question and will be followed
 	 by question mark on output. */
-      if (!mh_getyn_interactive (_("Do you want the standard MH path \"%s\""), mhdir))
+      if (!mh_getyn_interactive (_("Do you want the standard MH path %s"),
+				 mu_quotename (mhdir)))
 	{
 	  int local;
 	  char *p, *buf = NULL;
@@ -864,7 +866,7 @@ mh_real_install (char *name, int automode)
 			      MU_STREAM_WRITE | MU_STREAM_CREAT);
   if (rc)
     {
-      mu_error (_("cannot open file %s: %s"), name, mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create", name, rc);
       exit (1);
     }
   mu_stream_printf (profile, "Path: %s\n", mhdir);
@@ -1093,7 +1095,7 @@ mh_draft_message (const char *name, const char *msgspec, char **pname)
 	  exit (1);
 	}
       mu_mailbox_get_property (mbox, &prop);
-      mu_property_set_value (prop, "cur", mu_umaxtostr (0, uid), 1);
+      mu_property_set_value (prop, "cur", mu_umaxtostr (uid), 1);
     }
   else
     {
