@@ -326,7 +326,7 @@ parse_variable (struct mhl_ctx *ctx, mu_list_t formlist)
 	{
 	  if (strcmp (name, ","))
 	    {
-	      mu_error (_("expected ',', but found \"%s\""), name);
+	      mu_error (_("expected ',', but found '%s'"), name);
 	    }
 	  mhl_ctx_advance (ctx, 1);
 	}
