@@ -101,8 +101,7 @@ mh_whatnow_env_to_environ (struct mh_whatnow_env *wh)
 	  mu_message_get_uid (msg, &uid);
 	  if (prev_uid == 0)
 	    {
-	      s = mu_umaxtostr (0, uid);
-	      mu_opool_appendz (opool, s);
+	      mu_opool_appendz (opool, mu_umaxtostr (uid));
 	      mrange = 0;
 	    }
 	  else if (uid == prev_uid + 1)
@@ -112,12 +111,10 @@ mh_whatnow_env_to_environ (struct mh_whatnow_env *wh)
 	      if (mrange)
 		{
 		  mu_opool_append_char (opool, '-');
-		  s = mu_umaxtostr (0, prev_uid);
-		  mu_opool_appendz (opool, s);
+		  mu_opool_appendz (opool, mu_umaxtostr (prev_uid));
 		}
 	      mu_opool_append_char (opool, ' ');
-	      s = mu_umaxtostr (0, uid);
-	      mu_opool_appendz (opool, s);
+	      mu_opool_appendz (opool, mu_umaxtostr (uid));
 	      mrange = 0;
 	    }
 	}
@@ -125,8 +122,7 @@ mh_whatnow_env_to_environ (struct mh_whatnow_env *wh)
       if (mrange)
 	{
 	  mu_opool_append_char (opool, '-');
-	  s = mu_umaxtostr (0, prev_uid);
-	  mu_opool_appendz (opool, s);
+	  mu_opool_appendz (opool, mu_umaxtostr (prev_uid));
 	}
       mu_opool_append_char (opool, 0);
       s = mu_opool_finish (opool, NULL);
