@@ -932,7 +932,8 @@ compile_regexes (int argc, char **argv, struct regmatch *match)
 	{
 	  char errbuf[512];
 	  regerror (rc, &regs[i], errbuf, sizeof (errbuf));
-	  mu_error (_("error compiling `%s': %s"), argv[i], errbuf);
+	  mu_error (_("error compiling %s: %s"), mu_quotename (argv[i]),
+		    errbuf);
 	  errors++;
 	}
     }
@@ -1039,7 +1040,7 @@ _set_null (const char *val)
     include_zero = 1;
   else
     {
-      mu_error (_("bad value for `null' directive: %s"), val);
+      mu_error (_("bad value for 'null' directive: %s"), val);
       exit (EX_DATAERR);
     }
   return 0;
@@ -1276,8 +1277,7 @@ print_header (const char *name, mu_stream_t str)
   time_t t;
 
   time (&t);
-  mu_stream_printf (str, "# ");
-  mu_stream_printf (str, _("Database dump file created by %s on %s"),
+  mu_stream_printf (str, "# Database dump file created by %s on %s",
 		    PACKAGE_STRING,
 		    ctime (&t));
   mu_stream_printf (str, "#:version=%s\n", format->name);
@@ -1713,6 +1713,8 @@ clear_include_zero (struct mu_parseopt *po, struct mu_option *opt,
 static struct mu_option dbm_options[] = {
   MU_OPTION_GROUP (N_("Create Options")),
   { "file",   'f', N_("FILE"), MU_OPTION_DEFAULT,
+    /* TRANSLATORS: names in parentheses are dbm commands: don't translate
+       them. */
     N_("read input from FILE (with create, delete, add and replace)"),
     mu_c_string, &input_file },
   { "permissions", 'p', N_("NUM"), MU_OPTION_DEFAULT,
@@ -1733,7 +1735,8 @@ static struct mu_option dbm_options[] = {
   { "ignore-directives", 'I', N_("NAMES"), MU_OPTION_DEFAULT,
     N_("ignore the listed directives"),
     mu_c_string, NULL, set_ignore_directives },
-  
+
+  /* TRANSLATORS: list and dump are dbm command names. */
   MU_OPTION_GROUP (N_("List and Dump Options")),
   { "format",           'H', N_("TYPE"), MU_OPTION_DEFAULT,
     N_("select output format"),
@@ -1742,6 +1745,7 @@ static struct mu_option dbm_options[] = {
     N_("suppress format header"),
     mu_c_bool, &suppress_header },
   
+  /* TRANSLATORS: list, dump, and delete are dbm command names. */
   MU_OPTION_GROUP (N_("List, Dump and Delete Options")),
   { "glob",        'G', NULL, MU_OPTION_DEFAULT,
     N_("treat keys as globbing patterns"),
