@@ -218,7 +218,7 @@ main (int argc, char **argv)
 
 	  mu_stream_printf (str, "\n"); 
 	  mu_stream_printf (str, 
-			    _("Run `%s help COMMAND' to get help on a particular mailutils command."),
+			    _("Run '%s help COMMAND' to get help on a particular mailutils command."),
 			    mu_program_name);
 	  mu_stream_destroy (&str);
 	  exit (0);
