@@ -136,7 +136,7 @@ log_cipher (mu_stream_t stream)
   if (rc)
     {
       mu_diag_output (MU_DIAG_INFO, _("TLS established"));
-      mu_diag_output (MU_DIAG_ERROR, _("can't get TLS details: %s"),
+      mu_diag_output (MU_DIAG_ERROR, _("cannot get TLS details: %s"),
 		      mu_strerror (rc));
     }
   else
