@@ -46,7 +46,7 @@ pop3d_child_signal (int signo)
 {
   int code;
   
-  mu_diag_output (MU_DIAG_CRIT, _("got signal `%s'"), strsignal (signo));
+  mu_diag_output (MU_DIAG_CRIT, _("got signal %s"), strsignal (signo));
 
   switch (signo)
     {
