@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2023 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,9 +21,10 @@
 #include "readmsg.h"
 #include <fnmatch.h>
 #include <regex.h>
-#include "mailutils/cli.h"
-#include "mailutils/mu_auth.h"
-#include "mailutils/alloc.h"
+#include <mailutils/cli.h>
+#include <mailutils/mu_auth.h>
+#include <mailutils/alloc.h>
+#include <mailutils/cstr.h>
 #include "mu_umaxtostr.h"
 #include "muaux.h"
 
@@ -492,8 +493,8 @@ main (int argc, char **argv)
   if (status != 0)
     {
       if (mailbox_name)
-	mu_error (_("could not create mailbox `%s': %s"),
-		  mailbox_name,
+	mu_error (_("could not create mailbox %s: %s"),
+		  mu_quotename (mailbox_name),
 		  mu_strerror(status));
       else
 	mu_error (_("could not create default mailbox: %s"),
@@ -514,8 +515,8 @@ main (int argc, char **argv)
       mu_url_t url = NULL;
 
       mu_mailbox_get_url (mbox, &url);
-      mu_error (_("could not open mailbox `%s': %s"),
-		mu_url_to_string (url), mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open",
+		       mu_url_to_string (url), status);
       exit (2);
     }
 
